==> litecoin_0.16.3.orig.tar.xz: litecoin-0.16.3/src/qt/locale/bitcoin_ru.ts <==
<TS language="ru" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Кликните правой кнопкой для редактирования адреса или метки</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Создать новый адрес</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Копировать текущий выделенный адрес в буфер обмена</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Удалить текущий выбранный адрес из списка</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Экспортировать данные текущей вкладки в файл</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Экспорт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Выберите адрес для отправки перевода</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Выберите адрес для получения перевода</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Выбрать</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Адреса отправки</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Адреса получения</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Это ваши адреса Litecoin для отправки платежей. Всегда проверяйте количество и адрес получателя перед отправкой перевода.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Это ваши адреса Litecoin для приёма платежей. Рекомендуется использовать новый адрес получения для каждой транзакции.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Копировать &amp;адрес</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Копировать &amp;метку</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Экспортировать список адресов</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Текст, разделённый запятыми (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Экспорт не удался</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Произошла ошибка сохранения списка адресов в %1. Пожалуйста, повторите попытку.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Введите пароль</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Новый пароль</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Повторите новый пароль</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Показать пароль</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Зашифровать электронный кошелёк</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Для выполнения операции требуется пароль от вашего кошелька.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Разблокировать бумажник</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Расшифровать бумажник</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Изменить пароль</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Введите старый и новый пароль для кошелька.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Подтвердить шифрование кошелька</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Вы уверены, что хотите зашифровать ваш кошелёк?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Кошелёк зашифрован</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Расшифровка кошелька не удалась</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Маска подсети</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Заблокировано до</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Подписать &amp;сообщение...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Синхронизация с сетью...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Обзор</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Узел</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Транзакции</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Просмотр истории транзакций</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Закрыть приложение</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Около %1</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Параметры</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Изменить параметры конфигурации для %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Зашифровать кошелёк...</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Текст, разделённый запятыми (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Экспорт не удался</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Экспорт</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Экспортировать данные текущей вкладки в файл</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>The wallet will avoid paying less than the minimum relay fee.</source>
        <translation>Кошелёк постарается не платить меньше, чем минимальная комиссия передачи.</translation>
    </message>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation>Сумма транзакции не должна быть отрицательной</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Недостаточно средств</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Загрузка электронного кошелька...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>Не удаётся понизить версию электронного кошелька</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Загрузка завершена</translation>
    </message>
    </context>
</TS>

==> litecoin_0.17.1.orig.tar.xz: litecoin-0.17.1/src/qt/locale/bitcoin_ru.ts <==
<TS language="ru" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Кликните правой кнопкой для редактирования адреса или метки</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Создать новый адрес</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Копировать текущий выделенный адрес в буфер обмена</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Удалить текущий выбранный адрес из списка</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Введите адрес или метку для поиска</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Экспортировать данные текущей вкладки в файл</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Экспорт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Выберите адрес для отправки перевода</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Выберите адрес для получения перевода</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Выбрать</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Адреса отправки</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Адреса получения</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Это ваши адреса Litecoin для отправки платежей. Всегда проверяйте количество и адрес получателя перед отправкой перевода.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Это ваши адреса Litecoin для приёма платежей. Рекомендуется использовать новый адрес получения для каждой транзакции.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Копировать &amp;адрес</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Копировать &amp;метку</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Экспортировать список адресов</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Текст, разделённый запятыми (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Экспорт не удался</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Произошла ошибка сохранения списка адресов в %1. Пожалуйста, повторите попытку.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Введите пароль</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Новый пароль</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Повторите новый пароль</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Показать пароль</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Введите новый пароль бумажника.&lt;br/&gt;Используйте пароль, состоящий из &lt;b&gt;десяти или более случайных символов&lt;/b&gt;, или &lt;b&gt;восьми или более слов&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Зашифровать электронный кошелёк</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Для выполнения операции требуется пароль от вашего кошелька.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Разблокировать бумажник</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Данная операция требует введения пароля для расшифровки вашего бумажника.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Расшифровать бумажник</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Изменить пароль</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Введите старый и новый пароль для кошелька.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Подтвердить шифрование кошелька</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Предупреждение: если вы зашифруете бумажник и потеряете пароль, вы &lt;b&gt;ПОТЕРЯЕТЕ ВСЕ ВАШИ БИТКОИНЫ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Вы уверены, что хотите зашифровать ваш кошелёк?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Кошелёк зашифрован</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Не удалось зашифровать бумажник</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Разблокировка бумажника не удалась</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Расшифровка кошелька не удалась</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Маска подсети</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Заблокировано до</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Подписать &amp;сообщение...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Синхронизация с сетью...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Обзор</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Узел</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Транзакции</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Просмотр истории транзакций</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Закрыть приложение</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Около %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Показать информацию о Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Параметры</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Изменить параметры конфигурации для %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Зашифровать кошелёк...</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Кошелёк</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Кошелёк</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Transaction fee</source>
        <translation>Комиссия</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(нет метки)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Текст, разделённый запятыми (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Экспорт не удался</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Экспорт</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Экспортировать данные текущей вкладки в файл</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error initializing block database</source>
        <translation>Ошибка инициализации БД блоков</translation>
    </message>
    <message>
        <source>The wallet will avoid paying less than the minimum relay fee.</source>
        <translation>Кошелёк постарается не платить меньше, чем минимальная комиссия передачи.</translation>
    </message>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation>Сумма транзакции не должна быть отрицательной</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Недостаточно средств</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Загрузка индекса блоков...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Загрузка электронного кошелька...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>Не удаётся понизить версию электронного кошелька</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Сканирование...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Загрузка завершена</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
</TS>
